# zenmpx

[![PyPI - Version](https://img.shields.io/pypi/v/zenmpx.svg)](https://pypi.org/project/zenmpx)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/zenmpx.svg)](https://pypi.org/project/zenmpx)

-----

## Table of Contents

- [zenmpx](#zenmpx)
  - [Table of Contents](#table-of-contents)
  - [Installation](#installation)
  - [License](#license)

## Installation

```console
pip install zenmpx
```

## License

`zenmpx` All Rights Reserved.

This software is the exclusive property of [bernard jiang](mailto:bernardjiang5@outlook.com).

No part of this software may be used, copied, modified, distributed,
or otherwise exploited in any form without prior written permission
from the copyright holder.